@@ -3,11 +3,12 @@ package App::perlimports::Document;
 use Moo;
 use utf8;
 
-our $VERSION = '0.000022';
+our $VERSION = '0.000023';
 
 use App::perlimports::Annotations     ();
 use App::perlimports::ExportInspector ();
 use App::perlimports::Include         ();
+use App::perlimports::Sandbox         ();
 use File::Basename qw( fileparse );
 use List::Util qw( any uniq );
 use Module::Runtime qw( module_notional_filename );
@@ -874,6 +875,18 @@ sub _build_tidied_document {
             }
         }
 
+        # Let's see if the import itself might break something
+        if ( my $err
+            = App::perlimports::Sandbox::eval_pkg( $elem->module, "$elem" ) )
+        {
+            $self->logger->warning(
+                sprintf(
+                    'New include (%s) triggers error (%s)', $elem, $err
+                )
+            );
+            next;
+        }
+
         # https://github.com/Perl-Critic/PPI/issues/189
         my $inserted = $include->insert_before($elem);
         if ( !$inserted ) {
@@ -993,7 +1006,7 @@ App::perlimports::Document - Make implicit imports explicit
 
 =head1 VERSION
 
-version 0.000022
+version 0.000023
 
 =head2 inspector_for( $module_name )
 
